@@ -18,10 +18,12 @@ class XicsrtOpticDetector(XicsrtOpticMesh):
     """
     A class for detectors.
 
-    **Programming Notes**
+    Programming Notes
+    -----------------
 
     For now the detector class is exactly the same as the generic optic.
     In the future this may change based on defaults or how quantum efficiency is
     handled.
     """
+
     pass
