@@ -10,6 +10,28 @@ A set of mathematical utilities and vector convenience functions for XICSRT.
 
 import numpy as np
 
+
+def distance_point_to_line(origin, normal, point):
+    o = origin
+    n = normal
+    p = point
+    t = np.dot(p - o, n) / np.dot(n, n)
+    d = np.linalg.norm(np.outer(t, n) + o - p, axis=1)
+    return d
+
+
+def toarray(a):
+    """
+    Convert the input to a ndarray with at least 1 dimension.
+    This is similar to the numpy function atleast_1d, but has less overhead
+    and is jax compatible.
+    """
+    a = np.asarray(a)
+    if a.ndim == 0:
+        a = a.reshape(1)
+    return a
+
+
 def vector_angle(a, b):
     """
     Find the angle between two vectors.
@@ -25,6 +47,7 @@ def vector_angle(a, b):
     angle = np.arccos(dot)
     return angle
 
+
 def vector_rotate(a, b, theta):
     """
     Rotate vector a around vector b by an angle theta (radians)
@@ -41,6 +64,19 @@ def vector_rotate(a, b, theta):
     c = u + v * np.cos(theta) + w * np.sin(theta)
     return c
 
+
+def magnitude(vector):
+    """
+    Calculate magnitude of a vector or array of vectors.
+    """
+    if vector.ndim > 1:
+        mag = np.linalg.norm(vector, axis=1)
+    else:
+        mag = np.linalg.norm(vector)
+
+    return mag
+
+
 def normalize(vector):
     """
     Normalize a vector or an array of vectors.
@@ -58,10 +94,12 @@ def normalize(vector):
 
     return vector
 
+
 def sinusoidal_spiral(phi, b, r0, theta0):
     r = r0 * (np.sin(theta0 + (b-1)*phi)/np.sin(theta0))**(1/(b-1))
     return r
 
+
 def rotation_matrix(axis, theta):
     """
     Return the rotation matrix associated with counterclockwise rotation about
@@ -80,6 +118,7 @@ def rotation_matrix(axis, theta):
 
     return matrix
 
+
 def bragg_angle(wavelength, crystal_spacing):
     """
     The Bragg angle calculation is used so often that it deserves its own funct
@@ -206,4 +245,4 @@ def car_from_tor(point_tor, major_radius):
         point_car[1] = point_car[1] + vector[1]*point_tor[0]*np.cos(point_tor[1])
         point_car[2] = point_tor[0]*np.sin(point_tor[1])
 
-    return point_car
\ No newline at end of file
+    return point_car
